==> Catalyst-Controller-Atompub-0.3.7.tar.gz: Catalyst-Controller-Atompub-0.3.7/lib/Catalyst/Helper/Controller/Atompub/Service.pm <==
package Catalyst::Helper::Controller::Atompub::Service;

use strict;
use warnings;

sub mk_compclass {
    my($self, $helper) = @_;
    $helper->render_file('compclass', $helper->{file});
}

1;

=head1 NAME

Catalyst::Helper::Controller::Atompub::Service - Helper for Atom Service Document

=head1 SYNOPSIS

    $ perl script/myapp_create.pl controller MyService Atompub::Service

=head1 DESCRIPTION

Helper for the L<Catalyst> Atom Service Document.
See L<Catalyst::Controller::Atompub::Service>.

=head1 METHODS

=head2 mk_compclass

Makes the Atom Service Document class.

=head1 SEE ALSO

L<Catalyst::Controller::Atompub::Service>

=head1 AUTHOR

Takeru INOUE, E<lt>takeru.inoue _ gmail.comE<gt>

=head1 LICENCE AND COPYRIGHT

Copyright (c) 2007, Takeru INOUE C<< <takeru.inoue _ gmail.com> >>. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.

=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
SUCH DAMAGES.

=cut

__DATA__

=begin pod_to_ignore

__compclass__
package [% class %];

use strict;
use warnings;
use base qw(Catalyst::Controller::Atompub::Service);

sub modify_service {
    my($self, $c, $service) = @_;

    # Edit $service

    return $service;
}

=head1 NAME

[% class %] - Atom Service Document

=head1 SYNOPSIS

See L<[% app %]>.

=head1 DESCRIPTION

Atom Service Document class.

=head1 AUTHOR

[% author %]

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;

==> Catalyst-Controller-Atompub-0.5.4.tar.gz: Catalyst-Controller-Atompub-0.5.4/lib/Catalyst/Helper/Controller/Atompub/Service.pm <==
package Catalyst::Helper::Controller::Atompub::Service;

use strict;
use warnings;

sub mk_compclass {
    my($self, $helper) = @_;
    $helper->render_file('compclass', $helper->{file});
}

1;

=head1 NAME

Catalyst::Helper::Controller::Atompub::Service - Helper for Atom Service Document

=head1 SYNOPSIS

    $ perl script/myapp_create.pl controller MyService Atompub::Service

=head1 DESCRIPTION

Helper for the L<Catalyst> Atom Service Document.
See L<Catalyst::Controller::Atompub::Service>.

=head1 METHODS

=head2 mk_compclass

Makes the Atom Service Document class.

=head1 SEE ALSO

L<Catalyst::Controller::Atompub::Service>

=head1 AUTHOR

Takeru INOUE, E<lt>takeru.inoue _ gmail.comE<gt>

=head1 LICENCE AND COPYRIGHT

Copyright (c) 2007, Takeru INOUE C<< <takeru.inoue _ gmail.com> >>. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.

=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
SUCH DAMAGES.

=cut

__DATA__

=begin pod_to_ignore

__compclass__
package [% class %];

use strict;
use warnings;
use base qw(Catalyst::Controller::Atompub::Service);

# Edit Service Document
#sub modify_service {
#    my($self, $c, $service) = @_;
#    return $service;
#}

=head1 NAME

[% class %] - Atom Service Document

=head1 SYNOPSIS

See L<[% app %]>.

=head1 DESCRIPTION

Atom Service Document class.

=head1 AUTHOR

[% author %]

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
